@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import Optional
+from typing import Any, Optional
 
 from hostingde.model import Model
 
@@ -7,22 +7,23 @@ from hostingde.model import Model
 @dataclass
 class Account(Model):
     """
-        Name
-        Name of the Account
+    Name
+    Name of the Account
 
-        id
-        ID of this Account.
+    id
+    ID of this Account.
     """
 
     name: Optional[str]
     id: Optional[str]
 
-    def __init__(self, name: Optional[str], id: Optional[str]):
+    def __init__(self, name: Optional[str], id: Optional[str], **kwargs: Any):
         """
         The Account object a object.
         :param name: Namw of this Account
 
         :param id: ID of this Account.
         """
+        super().__init__(**kwargs)
         self.id: Optional[str] = id
         self.name: Optional[str] = name
